@@ -49,6 +49,8 @@ optionsProp: dict[str, Option] = {
 	),
 	"example_padding": IntOption(
 		comment="Padding for examples (in px)",
+		minim=0,
+		maxim=10_000,
 	),
 	"translitation": BoolOption(
 		comment="Add translitation (romaji) of keywords",
